* config.site: s/dyn/extatica/.
* README,
* bin/Makefile.am,
* bin/mk_swig_input,
* config/erbx,
* config/warning.m4,
* configure.ac,
* data/Makefile.am,
* data/function.cc,
* src/Makefile.am,
* src/all_methods.erb.cc,
* src/all_methods.erb.hh,
* src/config.hh.in,
* src/data.cc,
* src/data.hh,
* src/data.hxx,
* src/function.erb.cc,
* src/function.erb.hh,
* src/function_loader.cc,
* src/function_loader.hh,
* src/function_loader.rb,
* src/libiberty-fix.c,
* src/name_of.cc,
* src/name_of.hh,
* src/policy.cc,
* src/policy.hh,
* src/ruby_stream.cc,
* src/ruby_stream.hh,
* src/wrappers/Makefile.am,
* src/wrappers/milena.cc,
* src/wrappers/milena.hh,
* swig/Makefile.am,
* swig/mln.i,
* swig/python/Makefile.am,
* test/Makefile.am,
* test/test_containers.cc,
* test/test_damien.cc,
* test/test_function_loader.cc,
* test/test_methods.cc,
* test/test_milena.cc,
* test/test_var_and_val.cc,
* test/vaucanson/Makefile.am,
* test/wrappers/Makefile.am,
* test/wrappers/test-milena.cc:
s/libdyn/libextatica/.
s/libdynmilena/libextatica-milena/.
s/dyn-config/xtc-config/.
s/DYNDIR/XTCDIR/.
s/DYN_DATADIR/XTC_DATADIR/.
s/DYN_FIXTURES/XTC_FIXTURES/.
s/dyn/xtc/.
Adjust.
* bin/dyn-config.in,
* bin/yaml_to_dyn_decls,
* src/dyn.hh,
* swig/python/milena-libdynmilena.py,
* swig/python/milena-libdyn.py,
* swig/dyn.i:
Likewise.
Rename as...
* bin/xtc-config.in,
* bin/yaml_to_xtc_decls,
* src/extatica.hh,
* swig/python/milena-libextatica-milena.py,
* swig/python/milena-libextatica.py,
* swig/xtc.i:
...this.
---
extatica/ChangeLog | 72 ++++++++++++++++++++
extatica/README | 2 +-
extatica/bin/Makefile.am | 8 +-
extatica/bin/mk_swig_input | 4 +-
extatica/bin/{dyn-config.in => xtc-config.in} | 12 ++--
.../bin/{yaml_to_dyn_decls => yaml_to_xtc_decls} | 34 +++++-----
extatica/config.site | 2 +-
extatica/config/erbx | 4 +-
extatica/config/warning.m4 | 34 +++++-----
extatica/configure.ac | 16 ++--
extatica/data/Makefile.am | 12 ++--
extatica/data/function.cc | 2 +-
extatica/src/Makefile.am | 42 ++++++------
extatica/src/all_methods.erb.cc | 14 ++--
extatica/src/all_methods.erb.hh | 14 ++--
extatica/src/config.hh.in | 17 +++--
extatica/src/data.cc | 48 +++++++-------
extatica/src/data.hh | 29 ++++----
extatica/src/data.hxx | 32 +++++-----
extatica/src/{dyn.hh => extatica.hh} | 20 +++---
extatica/src/function.erb.cc | 18 +++---
extatica/src/function.erb.hh | 15 ++--
extatica/src/function_loader.cc | 59 ++++++++--------
extatica/src/function_loader.hh | 12 ++--
extatica/src/function_loader.rb | 13 ++--
extatica/src/libiberty-fix.c | 4 +-
extatica/src/name_of.cc | 8 +-
extatica/src/name_of.hh | 9 ++-
extatica/src/policy.cc | 10 ++--
extatica/src/policy.hh | 24 +++---
extatica/src/ruby_stream.cc | 8 +-
extatica/src/ruby_stream.hh | 8 +-
extatica/src/wrappers/Makefile.am | 6 +-
extatica/src/wrappers/milena.cc | 18 +++---
extatica/src/wrappers/milena.hh | 26 ++++----
extatica/swig/Makefile.am | 4 +-
extatica/swig/mln.i | 10 ++--
extatica/swig/python/Makefile.am | 26 ++++----
...ibdynmilena.py => milena-libextatica-milena.py} | 18 +++---
.../{milena-libdyn.py => milena-libextatica.py} | 36 +++++-----
extatica/swig/{dyn.i => xtc.i} | 28 ++++----
extatica/test/Makefile.am | 32 +++++-----
extatica/test/test_containers.cc | 11 ++--
extatica/test/test_damien.cc | 63 +++++++++---------
extatica/test/test_function_loader.cc | 25 ++++---
extatica/test/test_methods.cc | 9 ++-
extatica/test/test_milena.cc | 17 +++--
extatica/test/test_var_and_val.cc | 11 ++--
extatica/test/vaucanson/Makefile.am | 4 +-
extatica/test/wrappers/Makefile.am | 10 ++--
extatica/test/wrappers/test-milena.cc | 14 ++--
51 files changed, 530 insertions(+), 444 deletions(-)
rename extatica/bin/{dyn-config.in => xtc-config.in} (86%)
rename extatica/bin/{yaml_to_dyn_decls => yaml_to_xtc_decls} (87%)
rename extatica/src/{dyn.hh => extatica.hh} (89%)
rename extatica/swig/python/{milena-libdynmilena.py => milena-libextatica-milena.py}
(65%)
rename extatica/swig/python/{milena-libdyn.py => milena-libextatica.py} (52%)
rename extatica/swig/{dyn.i => xtc.i} (80%)
diff --git a/extatica/ChangeLog b/extatica/ChangeLog
index 911ffdf..74cee07 100644
--- a/extatica/ChangeLog
+++ b/extatica/ChangeLog
@@ -1,3 +1,75 @@
+2010-11-09 Roland Levillain <roland(a)lrde.epita.fr>
+
+ Rename Dyn as Extatica within the project.
+
+ * config.site: s/dyn/extatica/.
+ * README,
+ * bin/Makefile.am,
+ * bin/mk_swig_input,
+ * config/erbx,
+ * config/warning.m4,
+ * configure.ac,
+ * data/Makefile.am,
+ * data/function.cc,
+ * src/Makefile.am,
+ * src/all_methods.erb.cc,
+ * src/all_methods.erb.hh,
+ * src/config.hh.in,
+ * src/data.cc,
+ * src/data.hh,
+ * src/data.hxx,
+ * src/function.erb.cc,
+ * src/function.erb.hh,
+ * src/function_loader.cc,
+ * src/function_loader.hh,
+ * src/function_loader.rb,
+ * src/libiberty-fix.c,
+ * src/name_of.cc,
+ * src/name_of.hh,
+ * src/policy.cc,
+ * src/policy.hh,
+ * src/ruby_stream.cc,
+ * src/ruby_stream.hh,
+ * src/wrappers/Makefile.am,
+ * src/wrappers/milena.cc,
+ * src/wrappers/milena.hh,
+ * swig/Makefile.am,
+ * swig/mln.i,
+ * swig/python/Makefile.am,
+ * test/Makefile.am,
+ * test/test_containers.cc,
+ * test/test_damien.cc,
+ * test/test_function_loader.cc,
+ * test/test_methods.cc,
+ * test/test_milena.cc,
+ * test/test_var_and_val.cc,
+ * test/vaucanson/Makefile.am,
+ * test/wrappers/Makefile.am,
+ * test/wrappers/test-milena.cc:
+ s/libdyn/libextatica/.
+ s/libdynmilena/libextatica-milena/.
+ s/dyn-config/xtc-config/.
+ s/DYNDIR/XTCDIR/.
+ s/DYN_DATADIR/XTC_DATADIR/.
+ s/DYN_FIXTURES/XTC_FIXTURES/.
+ s/dyn/xtc/.
+ Adjust.
+ * bin/dyn-config.in,
+ * bin/yaml_to_dyn_decls,
+ * src/dyn.hh,
+ * swig/python/milena-libdynmilena.py,
+ * swig/python/milena-libdyn.py,
+ * swig/dyn.i:
+ Likewise.
+ Rename as...
+ * bin/xtc-config.in,
+ * bin/yaml_to_xtc_decls,
+ * src/extatica.hh,
+ * swig/python/milena-libextatica-milena.py,
+ * swig/python/milena-libextatica.py,
+ * swig/xtc.i:
+ ...this.
+
2010-11-08 Roland Levillain <roland(a)lrde.epita.fr>
Add support for configuration option `--with-milena' in Extatica.
diff --git a/extatica/README b/extatica/README
index 9fb6982..78ef1eb 100644
--- a/extatica/README
+++ b/extatica/README
@@ -26,6 +26,6 @@ From the repository:
CONFIG_SITE=`pwd`/../config.site ../configure --prefix=`pwd`/../_install
# You may want to add the `bin/' directory to your path, but it is
- # no longer mandatory (`dyn-config' from `bin/' used to be required
+ # no longer mandatory (`xtc-config' from `bin/' used to be required
# by programs compiled with our system).
export PATH=$PATH:`pwd`/bin
diff --git a/extatica/bin/Makefile.am b/extatica/bin/Makefile.am
index 6aa9a50..4e0846d 100644
--- a/extatica/bin/Makefile.am
+++ b/extatica/bin/Makefile.am
@@ -14,7 +14,7 @@
# You should have received a copy of the GNU General Public License
# along with Olena. If not, see <http://www.gnu.org/licenses/>.
-bin_SCRIPTS = dyn-config
-# FIXME put dyn- before these binaries
-dist_noinst_SCRIPTS = mk_swig_input swig_tree_to_yaml yaml_to_dyn_decls
-BUILT_SOURCES = dyn-config
+bin_SCRIPTS = xtc-config
+# FIXME put xtc- before these binaries
+dist_noinst_SCRIPTS = mk_swig_input swig_tree_to_yaml yaml_to_xtc_decls
+BUILT_SOURCES = xtc-config
diff --git a/extatica/bin/mk_swig_input b/extatica/bin/mk_swig_input
index b29cecd..5e2e358 100755
--- a/extatica/bin/mk_swig_input
+++ b/extatica/bin/mk_swig_input
@@ -1,6 +1,6 @@
#! /usr/bin/env ruby
-# Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE).
+# Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -38,7 +38,7 @@ File.open('all.hh', 'w') do |all|
end
end
dirs = ARGV.map {|x| '-I' + x}
-`g++ #{dirs.join ' '} -I. #{CFLAGS} -I#{DYNDIR} #{flags} -E all.hh | grep
'^#.*vaucanson'`.to_a.reverse_each do |line|
+`g++ #{dirs.join ' '} -I. #{CFLAGS} -I#{XTCDIR} #{flags} -E all.hh | grep
'^#.*vaucanson'`.to_a.reverse_each do |line|
line.chomp!
line.gsub!(/^.*include\/(vaucanson\/.*)".*$/, '\1')
next unless line =~ patt
diff --git a/extatica/bin/dyn-config.in b/extatica/bin/xtc-config.in
similarity index 86%
rename from extatica/bin/dyn-config.in
rename to extatica/bin/xtc-config.in
index 84b7b0e..7b450d7 100755
--- a/extatica/bin/dyn-config.in
+++ b/extatica/bin/xtc-config.in
@@ -1,6 +1,6 @@
#! /usr/bin/env ruby
-# Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE).
+# Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -23,7 +23,7 @@ def expand ( var, binding )
var.gsub(/\$\{(.*)\}/) { eval($1, binding) }
end
-name = 'libdyn'
+name = 'libextatica'
version = '0.1'
prefix = Pathname.new('@prefix@')
includedir = expand('@includedir@', binding)
@@ -33,14 +33,14 @@ exec_prefix = expand('@exec_prefix@', binding)
libdir = expand('@libdir@', binding)
libtool_flags = '-export-dynamic'
-libdir_libdyn_la = Pathname.new("#{libdir}/libdyn.la")
-if libdir_libdyn_la.exist? # FIXME Perhaps is assertion is bad.
+libdir_libextatica_la = Pathname.new("#{libdir}/libextatica.la")
+if libdir_libextatica_la.exist? # FIXME Perhaps is assertion is bad.
cflags = "-I#{includedir}"
libtool = 'libtool' # Hope that libtool is installed
- libtool_libs = "#{libdir_libdyn_la} #{libtool_flags}"
+ libtool_libs = "#{libdir_libextatica_la} #{libtool_flags}"
else
cflags = "-I#{top_builddir}/src -I#{top_srcdir}/src"
- libtool_libs = "#{top_builddir}/src/libdyn.la #{libtool_flags}"
+ libtool_libs = "#{top_builddir}/src/libextatica.la #{libtool_flags}"
libtool = "#{top_builddir}/libtool"
end
diff --git a/extatica/bin/yaml_to_dyn_decls b/extatica/bin/yaml_to_xtc_decls
similarity index 87%
rename from extatica/bin/yaml_to_dyn_decls
rename to extatica/bin/yaml_to_xtc_decls
index 52ad7aa..3965f0d 100755
--- a/extatica/bin/yaml_to_dyn_decls
+++ b/extatica/bin/yaml_to_xtc_decls
@@ -1,6 +1,6 @@
#! /usr/bin/env ruby
-# Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE).
+# Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -85,17 +85,17 @@ class Dumper
@states.pop
puts '// };'
end
- def print_dyn ( key, tree )
+ def print_xtc ( key, tree )
return if tree.nil?
case tree
when Array
tree.each do |node|
- print_dyn(nil, node)
+ print_xtc(nil, node)
end
return
when Hash
if tree.size == 1
- print_dyn(*tree.to_a.first)
+ print_xtc(*tree.to_a.first)
return
end
when String
@@ -116,7 +116,7 @@ class Dumper
case key
when 'namespace'
namespace tree.name do
- print_dyn nil, tree.contents
+ print_xtc nil, tree.contents
end
when 'struct', 'class'
name = (@namespace[1..-1] + [tree.name]).join('::')
@@ -147,7 +147,7 @@ class Dumper
=end
end
struct tree.name, name do
- print_dyn nil, tree.contents
+ print_xtc nil, tree.contents
end
when 'cdecl'
node_name = tree.name
@@ -165,10 +165,10 @@ class Dumper
end
when 'include'
@includes << tree.name
- print_dyn nil, tree.contents
+ print_xtc nil, tree.contents
@includes.pop
# when 'constructor'
- # dump "dyn::ctor(#{convert_params(tree.parms)})"
+ # dump "xtc::ctor(#{convert_params(tree.parms)})"
end
end
def print_all_methods
@@ -188,26 +188,26 @@ dumper = Dumper.new
root = tree.rpath_find(:first, ARGV[0] || 'top/contents/include/*name/vcsn\.i')
# puts root.to_yaml
puts '// ------------------------------------------------ '
-puts '// dyn_vaucanson_dyn_mirror.hh'
-File.open('dyn_vaucanson_dyn_mirror.hh', 'w') do
|dyn_vaucanson_dyn_mirror_hh|
- dumper.with(dyn_vaucanson_dyn_mirror_hh) do
- dumper.namespace 'dyn' do
- dumper.print_dyn nil, root['contents']
+puts '// xtc_vaucanson_xtc_mirror.hh'
+File.open('xtc_vaucanson_xtc_mirror.hh', 'w') do
|xtc_vaucanson_xtc_mirror_hh|
+ dumper.with(xtc_vaucanson_xtc_mirror_hh) do
+ dumper.namespace 'xtc' do
+ dumper.print_xtc nil, root['contents']
end
end
end
puts '// ------------------------------------------------ '
puts '// all_methods.yml'
-File.open('dyn_vaucanson_methods.yml', 'w') do |all_methods_yml|
+File.open('xtc_vaucanson_methods.yml', 'w') do |all_methods_yml|
dumper.with(all_methods_yml) do
dumper.print_all_methods
end
end
=begin
puts '// ------------------------------------------------ '
-puts '// dyn_vaucanson_mlc_name.hh'
-File.open('dyn_vaucanson_mlc_name.hh', 'w') do
|dyn_vaucanson_mlc_name_hh|
- dumper.with(dyn_vaucanson_mlc_name_hh) do
+puts '// xtc_vaucanson_mlc_name.hh'
+File.open('xtc_vaucanson_mlc_name.hh', 'w') do
|xtc_vaucanson_mlc_name_hh|
+ dumper.with(xtc_vaucanson_mlc_name_hh) do
dumper.print_mlc_set_names
end
end
diff --git a/extatica/config.site b/extatica/config.site
index 760273e..50b8c42 100644
--- a/extatica/config.site
+++ b/extatica/config.site
@@ -1,6 +1,6 @@
# -*- shell-script -*-
-if test $PACKAGE_TARNAME == dyn; then
+if test $PACKAGE_TARNAME == extatica; then
# Use the cache.
cache_file=config.cache
diff --git a/extatica/config/erbx b/extatica/config/erbx
index 1cb423f..95f6e43 100755
--- a/extatica/config/erbx
+++ b/extatica/config/erbx
@@ -1,6 +1,6 @@
#! /usr/bin/env ruby
-# Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE).
+# Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -17,7 +17,7 @@
# along with Olena. If not, see <http://www.gnu.org/licenses/>.
# For this project only
-DYN_MAX_ARGUMENTS = 10
+XTC_MAX_ARGUMENTS = 10
ALL_METHODS = { 'fake_method' => ['*'] }
# end
diff --git a/extatica/config/warning.m4 b/extatica/config/warning.m4
index 677c781..f06f344 100644
--- a/extatica/config/warning.m4
+++ b/extatica/config/warning.m4
@@ -1,6 +1,6 @@
# Finding valid warning flags for the C and C++ Compilers. -*-Autoconf-*-
#
-# Copyright (C) 2003, 2006, 2009 Free Software Foundation, Inc.
+# Copyright (C) 2003, 2006, 2009, 2010 Free Software Foundation, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
@@ -36,16 +36,16 @@ rm -f conftest.$ac_objext m4_ifval([$1], [conftest.$ac_ext])[]dnl
])# AC_COMPILE_STDERR_IFELSE
-# DYN_COMPILER_FLAGS_NAME
+# XTC_COMPILER_FLAGS_NAME
# ----------------------
# Return the name of the FLAGS variable for the current language.
-m4_define([DYN_COMPILER_FLAGS_NAME],
+m4_define([XTC_COMPILER_FLAGS_NAME],
[AC_LANG_CASE([C], [CFLAGS],
[C++], [CXXFLAGS])[]dnl
-])# DYN_COMPILER_FLAGS_NAME
+])# XTC_COMPILER_FLAGS_NAME
-# DYN_COMPILER_OPTION_IF(OPTION, [IF-SUPPORTED], [IF-NOT-SUPPORTED])
+# XTC_COMPILER_OPTION_IF(OPTION, [IF-SUPPORTED], [IF-NOT-SUPPORTED])
# -----------------------------------------------------------------
# icc doesn't choke on unknown options, it will just issue warnings
# (even with -Werror). So we grep stderr for any message that says an
@@ -59,13 +59,13 @@ m4_define([DYN_COMPILER_FLAGS_NAME],
# cc1plus: warning: ignoring command line option '-Wbad-function-cast'
#
# Pay attention not to give grep a regexp starting with "-".
-AC_DEFUN([DYN_COMPILER_OPTION_IF],
+AC_DEFUN([XTC_COMPILER_OPTION_IF],
[AS_VAR_PUSHDEF([ac_Option],
[ac_cv_[]_AC_LANG_ABBREV[]_supports_$1])dnl
AC_CACHE_CHECK([whether _AC_LANG compiler accepts $1],
[ac_Option],
-[ac_save_[]DYN_COMPILER_FLAGS_NAME=$DYN_COMPILER_FLAGS_NAME
-DYN_COMPILER_FLAGS_NAME="$DYN_COMPILER_FLAGS_NAME $1"
+[ac_save_[]XTC_COMPILER_FLAGS_NAME=$XTC_COMPILER_FLAGS_NAME
+XTC_COMPILER_FLAGS_NAME="$XTC_COMPILER_FLAGS_NAME $1"
ac_Option=no
AC_COMPILE_STDERR_IFELSE([AC_LANG_PROGRAM],
[if (grep -E 'm4_do([ignoring option],
@@ -76,14 +76,14 @@ AC_COMPILE_STDERR_IFELSE([AC_LANG_PROGRAM],
) >/dev/null 2>&1; then :; else
ac_Option=yes
fi])
-DYN_COMPILER_FLAGS_NAME=$ac_save_[]DYN_COMPILER_FLAGS_NAME
+XTC_COMPILER_FLAGS_NAME=$ac_save_[]XTC_COMPILER_FLAGS_NAME
])
AS_VAR_IF([ac_Option], [yes], [$2], [$3])dnl
AS_VAR_POPDEF([ac_Option])dnl
-])# DYN_COMPILER_OPTION_IF
+])# XTC_COMPILER_OPTION_IF
-# DYN_CXX_WARNINGS(OPTIONS)
+# XTC_CXX_WARNINGS(OPTIONS)
# ------------------------
# Check whether the C++ compiler support the OPTION, and if it
# does, append it to WARNING_CXXFLAGS.
@@ -94,15 +94,15 @@ AS_VAR_POPDEF([ac_Option])dnl
#
# but not when used alone. This also demonstrates the importance of the
# order.
-AC_DEFUN([DYN_CXX_WARNINGS],
-[ac_save_compiler_flags=$DYN_COMPILER_FLAGS_NAME
+AC_DEFUN([XTC_CXX_WARNINGS],
+[ac_save_compiler_flags=$XTC_COMPILER_FLAGS_NAME
m4_foreach([AC_Option], [$1],
- [DYN_COMPILER_OPTION_IF(AC_Option,
+ [XTC_COMPILER_OPTION_IF(AC_Option,
[WARNING_CXXFLAGS="$WARNING_CXXFLAGS AC_Option"
- DYN_COMPILER_FLAGS_NAME="$ac_save_compiler_flags $WARNING_FLAGS"])
+ XTC_COMPILER_FLAGS_NAME="$ac_save_compiler_flags $WARNING_FLAGS"])
dnl Newlines inserted on purpose, to avoid erroneous concatenations.
])
-DYN_COMPILER_FLAGS_NAME=$ac_save_compiler_flags
+XTC_COMPILER_FLAGS_NAME=$ac_save_compiler_flags
AC_SUBST([WARNING_CXXFLAGS])
-])# DYN_CXX_WARNINGS(OPTIONS)
+])# XTC_CXX_WARNINGS(OPTIONS)
diff --git a/extatica/configure.ac b/extatica/configure.ac
index a22bf98..888c39d 100644
--- a/extatica/configure.ac
+++ b/extatica/configure.ac
@@ -19,8 +19,8 @@ AC_PREREQ([2.61])
# Catch some macros that are not expanded.
m4_pattern_forbid([^AC_LIBLTDL_])
-m4_pattern_forbid([^DYN_])
-m4_pattern_allow([^DYN_FIXTURES$])
+m4_pattern_forbid([^XTC_])
+m4_pattern_allow([^XTC_FIXTURES$])
m4_pattern_forbid([^ERB$])
m4_pattern_forbid([^RBCONFIG$])
@@ -51,7 +51,7 @@ if test "$GXX" = yes; then
fi
# Use good warnings.
-DYN_CXX_WARNINGS([[-Wall],
+XTC_CXX_WARNINGS([[-Wall],
[-W],
[-Wcast-align],
[-Wcast-qual],
@@ -194,11 +194,11 @@ my_abs_srcdir=`cd $srcdir && pwd`
my_abs_builddir=`pwd`
# FIXME: Remove me when function_loader will be pure C++
-AC_SUBST([DYNDIR], [$my_abs_srcdir/src])
+AC_SUBST([XTCDIR], [$my_abs_srcdir/src])
-AC_SUBST([DYN_DATADIR], [$my_abs_builddir/data])
+AC_SUBST([XTC_DATADIR], [$my_abs_builddir/data])
-AC_SUBST([DYN_FIXTURES], [$my_abs_srcdir/test/fixtures])
+AC_SUBST([XTC_FIXTURES], [$my_abs_srcdir/test/fixtures])
## -------- ##
## Milena. ##
@@ -254,7 +254,7 @@ AM_CONFIG_HEADER([_config/config.h])
AC_CONFIG_FILES([
Makefile
bin/Makefile
- bin/dyn-config
+ bin/xtc-config
libmd5/Makefile
src/Makefile
src/config.hh
@@ -265,7 +265,7 @@ AC_CONFIG_FILES([
test/Makefile
test/vaucanson/Makefile
test/wrappers/Makefile
-], [chmod +x bin/dyn-config])
+], [chmod +x bin/xtc-config])
# Instantiate the output files.
AC_OUTPUT
diff --git a/extatica/data/Makefile.am b/extatica/data/Makefile.am
index a9d9d93..f3f7982 100644
--- a/extatica/data/Makefile.am
+++ b/extatica/data/Makefile.am
@@ -17,13 +17,13 @@
# Do not install me.
-lib_LTLIBRARIES = libdyn_function.la
+lib_LTLIBRARIES = libextatica_function.la
# FIXME: This is probably not portable!
-# libdyn_function_la_LDFLAGS = `dyn-config --libtool-libs`
-# libdyn_function_la_CXXFLAGS = `dyn-config --cflags`
-libdyn_function_la_LDFLAGS = $(top_builddir)/src/libdyn.la -export-dynamic
-libdyn_function_la_CPPFLAGS = -I$(top_builddir)/src -I$(top_srcdir)/src
-libdyn_function_la_SOURCES = function.cc
+# libextatica_function_la_LDFLAGS = `xtc-config --libtool-libs`
+# libextatica_function_la_CXXFLAGS = `xtc-config --cflags`
+libextatica_function_la_LDFLAGS = $(top_builddir)/src/libextatica.la -export-dynamic
+libextatica_function_la_CPPFLAGS = -I$(top_builddir)/src -I$(top_srcdir)/src
+libextatica_function_la_SOURCES = function.cc
pkgdata_DATA = Makefile.template Makefile.repository
diff --git a/extatica/data/function.cc b/extatica/data/function.cc
index 7c5a043..e63aa06 100644
--- a/extatica/data/function.cc
+++ b/extatica/data/function.cc
@@ -1,4 +1,4 @@
-#include "dyn-light.hh"
+#include "xtc-light.hh"
int foo()
{
diff --git a/extatica/src/Makefile.am b/extatica/src/Makefile.am
index ab53eb2..1ca9d66 100644
--- a/extatica/src/Makefile.am
+++ b/extatica/src/Makefile.am
@@ -17,19 +17,19 @@
SUBDIRS = . wrappers
-include_HEADERS = dyn-all.hh dyn-light.hh
-lib_LTLIBRARIES = libdyn.la
+include_HEADERS = xtc-all.hh xtc-light.hh
+lib_LTLIBRARIES = libextatica.la
ERB = ruby $(top_srcdir)/config/erbx
-dyn_light_hh_deps = \
+xtc_light_hh_deps = \
$(srcdir)/name_of.hh \
function.hh \
all_methods.hh \
$(srcdir)/data.hh \
$(srcdir)/policy.hh
-dyn_all_hh_deps = \
+xtc_all_hh_deps = \
config.hh \
$(srcdir)/name_of.hh \
function.hh \
@@ -37,7 +37,7 @@ dyn_all_hh_deps = \
$(srcdir)/data.hh \
$(srcdir)/data.hxx \
$(srcdir)/function_loader.hh \
- $(srcdir)/dyn.hh
+ $(srcdir)/extatica.hh
# Ask Make to build these first since they are #include'd.
BUILT_SOURCES = \
@@ -48,13 +48,13 @@ BUILT_SOURCES = \
# Clean generated files.
CLEANFILES = \
$(BUILT_SOURCES) \
- dyn-all.hh \
- dyn-light.hh \
+ xtc-all.hh \
+ xtc-light.hh \
all_methods.cc \
function.cc
-libdyn_la_SOURCES = \
- dyn.hh \
+libextatica_la_SOURCES = \
+ extatica.hh \
data.hh data.hxx data.cc \
function_loader.hh function_loader.cc \
name_of.hh name_of.cc \
@@ -62,7 +62,7 @@ libdyn_la_SOURCES = \
ruby_stream.hh ruby_stream.cc \
ansidecl.h demangle.h
-nodist_libdyn_la_SOURCES = \
+nodist_libextatica_la_SOURCES = \
all_methods.hh all_methods.cc \
function.hh function.cc
@@ -74,21 +74,21 @@ EXTRA_DIST = \
# MacPorts), but missing on Mac OS X. This is just a workaround. We
# should file a problem report to the MacPorts about this.
if DARWIN
- libdyn_la_SOURCES += libiberty-fix.c
+ libextatica_la_SOURCES += libiberty-fix.c
endif DARWIN
RUBY_LIBRUBYARG_SHARED = @RUBY_LIBRUBYARG_SHARED@
-libdyn_la_LIBADD = \
+libextatica_la_LIBADD = \
$(RUBY_LIBRUBYARG_SHARED) \
$(LIBLTDL) \
$(top_builddir)/libmd5/libmd5.la \
$(BOOST_FILESYSTEM_LIBS)
-libdyn_la_DEPENDENCIES = $(LTDLDEPS)
+libextatica_la_DEPENDENCIES = $(LTDLDEPS)
RUBY_topdir = @RUBY_topdir@
-libdyn_la_CPPFLAGS = \
+libextatica_la_CPPFLAGS = \
$(LTDLINCL) \
$(BOOST_CPPFLAGS) \
-I$(top_builddir) \
@@ -96,8 +96,8 @@ libdyn_la_CPPFLAGS = \
-I. \
-I$(top_srcdir)/libmd5 \
-I$(RUBY_topdir)
-libdyn_la_CXXFLAGS = $(WARNING_CXXFLAGS)
-libdyn_la_LDFLAGS = -version-info 0:1:0 $(BOOST_FILESYSTEM_LDFLAGS)
+libextatica_la_CXXFLAGS = $(WARNING_CXXFLAGS)
+libextatica_la_LDFLAGS = -version-info 0:1:0 $(BOOST_FILESYSTEM_LDFLAGS)
#############
@@ -106,27 +106,27 @@ libdyn_la_LDFLAGS = -version-info 0:1:0 $(BOOST_FILESYSTEM_LDFLAGS)
cut_local_includes = grep -v '^.[\t ]*include[\t ]*".*"'
-dyn-all.hh: $(dyn_all_hh_deps)
+xtc-all.hh: $(xtc_all_hh_deps)
rm -f $@
rm -f $@.tmp.1
rm -f $@.tmp.2
echo "// Generated by make. Do not edit by hand." >$@.tmp.1
echo >>$@.tmp.1
- echo "#define DYN_FULL_IMPLEMENTATION" >>$@.tmp.1
+ echo "#define XTC_FULL_IMPLEMENTATION" >>$@.tmp.1
echo >>$@.tmp.1
- cat $(dyn_all_hh_deps) >>$@.tmp.1
+ cat $(xtc_all_hh_deps) >>$@.tmp.1
$(cut_local_includes) $@.tmp.1 >>$@.tmp.2
rm -f $@.tmp.1
mv $@.tmp.2 $@
chmod -w $@
-dyn-light.hh: $(dyn_light_hh_deps)
+xtc-light.hh: $(xtc_light_hh_deps)
rm -f $@
rm -f $@.tmp.1
rm -f $@.tmp.2
echo "// Generated by make. Do not edit by hand." >$@.tmp.1
echo >>$@.tmp.1
- cat $(dyn_light_hh_deps) >>$@.tmp.1
+ cat $(xtc_light_hh_deps) >>$@.tmp.1
$(cut_local_includes) $@.tmp.1 >>$@.tmp.2
rm -f $@.tmp.1
mv $@.tmp.2 $@
diff --git a/extatica/src/all_methods.erb.cc b/extatica/src/all_methods.erb.cc
index 531d525..b34c9d9 100644
--- a/extatica/src/all_methods.erb.cc
+++ b/extatica/src/all_methods.erb.cc
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,18 +23,18 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_ALL_METHODS_CC
-# define DYN_ALL_METHODS_CC
+#ifndef XTC_ALL_METHODS_CC
+# define XTC_ALL_METHODS_CC
-# define DYN_FULL_IMPLEMENTATION
+# define XTC_FULL_IMPLEMENTATION
# include "all_methods.hh"
# include "data.hh"
# include "function.hh"
-namespace dyn
+namespace xtc
{
-<%- (DYN_MAX_ARGUMENTS - 1).times do |i| -%>
+<%- (XTC_MAX_ARGUMENTS - 1).times do |i| -%>
<%- arguments = (0 .. i - 1).map { |j| "const data& arg#{j}" } -%>
<%- objects = (0 .. i - 1).map { |j| "arg#{j}" } -%>
@@ -59,4 +59,4 @@ namespace dyn
}
-#endif // ! DYN_ALL_METHODS_CC
+#endif // ! XTC_ALL_METHODS_CC
diff --git a/extatica/src/all_methods.erb.hh b/extatica/src/all_methods.erb.hh
index a838d3b..43b753e 100644
--- a/extatica/src/all_methods.erb.hh
+++ b/extatica/src/all_methods.erb.hh
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,12 +23,12 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_ALL_METHODS_HH
-# define DYN_ALL_METHODS_HH
+#ifndef XTC_ALL_METHODS_HH
+# define XTC_ALL_METHODS_HH
# include <string>
-namespace dyn
+namespace xtc
{
struct data;
@@ -40,8 +40,8 @@ namespace dyn
virtual ~all_methods() {};
-# ifdef DYN_FULL_IMPLEMENTATION
-<%- (DYN_MAX_ARGUMENTS - 1).times do |i| -%>
+# ifdef XTC_FULL_IMPLEMENTATION
+<%- (XTC_MAX_ARGUMENTS - 1).times do |i| -%>
<%- arguments = (0 .. i - 1).map { |j| "const data& arg#{j}" } -%>
<%- ALL_METHODS.each do |meth, includes| -%>
@@ -59,4 +59,4 @@ namespace dyn
}
-#endif // ! DYN_ALL_METHODS_HH
+#endif // ! XTC_ALL_METHODS_HH
diff --git a/extatica/src/config.hh.in b/extatica/src/config.hh.in
index 1939af5..61312d7 100644
--- a/extatica/src/config.hh.in
+++ b/extatica/src/config.hh.in
@@ -1,6 +1,7 @@
// -*- C++ -*-
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE).
This file is part of Olena.
@@ -25,12 +26,14 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_CONFIG_HH
-# define DYN_CONFIG_HH
+#ifndef XTC_CONFIG_HH
+# define XTC_CONFIG_HH
-# define DYNDIR "@DYNDIR@"
-# define DYN_DATADIR "@DYN_DATADIR@"
-# define DYN_FIXTURES "@DYN_FIXTURES@"
+# define XTCDIR "@XTCDIR@"
+# define XTC_DATADIR "@XTC_DATADIR@"
+# define XTC_FIXTURES "@XTC_FIXTURES@"
+// FIXME: Should be moved elsewhere or handled otherwise (Milena
+// should be an optional dependency of Extatica).
# define MILENA_DIR "@MILENA_DIR@"
-#endif // ! DYN_CONFIG_HH
+#endif // ! XTC_CONFIG_HH
diff --git a/extatica/src/data.cc b/extatica/src/data.cc
index 2912e35..305e826 100644
--- a/extatica/src/data.cc
+++ b/extatica/src/data.cc
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,29 +23,29 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_DATA_CC
-# define DYN_DATA_CC
+#ifndef XTC_DATA_CC
+# define XTC_DATA_CC
-# include "dyn.hh"
+# include "extatica.hh"
# include "data.hh"
-# ifdef DYNDEBUG
+# ifdef XTCDEBUG
# include <iostream>
# else
# include <fstream>
# endif
-namespace dyn {
+namespace xtc {
-# ifdef DYNDEBUG
+# ifdef XTCDEBUG
std::ostream& logger(std::cerr);
# else
# ifdef NDEBUG
std::ofstream dev_null("/dev/null");
std::ostream& logger(dev_null);
# else
- std::ofstream dyn_log("dyn.log");
- std::ostream& logger(dyn_log);
+ std::ofstream xtc_log("xtc.log");
+ std::ostream& logger(xtc_log);
# endif
# endif
@@ -112,42 +112,42 @@ namespace dyn {
}
}
-std::ostream& operator<<(std::ostream& ostr, const dyn::data& d)
+std::ostream& operator<<(std::ostream& ostr, const xtc::data& d)
{
- return dyn::internal::operator_push(ostr, d).get_ref_on<std::ostream>();
+ return xtc::internal::operator_push(ostr, d).get_ref_on<std::ostream>();
}
-std::istream& operator>>(std::istream& istr, dyn::data& d)
+std::istream& operator>>(std::istream& istr, xtc::data& d)
{
- return dyn::internal::operator_pop(istr, d).get_ref_on<std::istream>();
+ return xtc::internal::operator_pop(istr, d).get_ref_on<std::istream>();
}
-dyn::data& operator++(dyn::data& d)
+xtc::data& operator++(xtc::data& d)
{
- dyn::internal::operator_incr(d);
+ xtc::internal::operator_incr(d);
return d;
}
-dyn::data& operator--(dyn::data& d)
+xtc::data& operator--(xtc::data& d)
{
- dyn::internal::operator_decr(d);
+ xtc::internal::operator_decr(d);
return d;
}
-bool operator!=(const dyn::data& lhs, const dyn::data& rhs)
+bool operator!=(const xtc::data& lhs, const xtc::data& rhs)
{
- return dyn::internal::operator_not_equal(lhs, rhs);
+ return xtc::internal::operator_not_equal(lhs, rhs);
}
-bool operator==(const dyn::data& lhs, const dyn::data& rhs)
+bool operator==(const xtc::data& lhs, const xtc::data& rhs)
{
- return dyn::internal::operator_equal(lhs, rhs);
+ return xtc::internal::operator_equal(lhs, rhs);
}
-dyn::data operator+(const dyn::data& lhs, const dyn::data& rhs)
+xtc::data operator+(const xtc::data& lhs, const xtc::data& rhs)
{
- return dyn::internal::operator_plus(lhs, rhs);
+ return xtc::internal::operator_plus(lhs, rhs);
}
-#endif // ! DYN_DATA_CC
+#endif // ! XTC_DATA_CC
diff --git a/extatica/src/data.hh b/extatica/src/data.hh
index 70b4f99..553580e 100644
--- a/extatica/src/data.hh
+++ b/extatica/src/data.hh
@@ -1,4 +1,5 @@
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE).
This file is part of Olena.
@@ -23,8 +24,8 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_DATA_HH
-# define DYN_DATA_HH
+#ifndef XTC_DATA_HH
+# define XTC_DATA_HH
# include <string>
# include <cassert>
@@ -32,7 +33,7 @@
# include "name_of.hh"
# include "all_methods.hh"
-namespace dyn {
+namespace xtc {
extern std::ostream& logger;
@@ -355,7 +356,7 @@ namespace dyn {
bool is_const()
{
std::string type_(type());
- return type_.find("dyn::data_proxy_by_ref<") == 0
+ return type_.find("xtc::data_proxy_by_ref<") == 0
&& type_.rfind("const>") == type_.size() - 6;
}
@@ -419,26 +420,26 @@ namespace dyn {
}
-template <typename T, dyn::policy::type policy>
-struct dyn_choose_data_proxy
+template <typename T, xtc::policy::type policy>
+struct xtc_choose_data_proxy
{
- typedef dyn::data_proxy_by_cpy<T> ret;
+ typedef xtc::data_proxy_by_cpy<T> ret;
};
template <typename T>
-struct dyn_choose_data_proxy<T, dyn::policy::is_ref>
+struct xtc_choose_data_proxy<T, xtc::policy::is_ref>
{
- typedef dyn::data_proxy_by_ref<T> ret;
+ typedef xtc::data_proxy_by_ref<T> ret;
};
template <typename T>
-struct dyn_choose_data_proxy<T, (dyn::policy::type)(dyn::policy::is_ref +
dyn::policy::is_const)>
+struct xtc_choose_data_proxy<T, (xtc::policy::type)(xtc::policy::is_ref +
xtc::policy::is_const)>
{
- typedef dyn::data_proxy_by_ref<const T> ret;
+ typedef xtc::data_proxy_by_ref<const T> ret;
};
-# ifdef DYN_FULL_IMPLEMENTATION
+# ifdef XTC_FULL_IMPLEMENTATION
# include "data.hxx"
# endif
-#endif // ! DYN_DATA_HH
+#endif // ! XTC_DATA_HH
diff --git a/extatica/src/data.hxx b/extatica/src/data.hxx
index 2990596..e727a75 100644
--- a/extatica/src/data.hxx
+++ b/extatica/src/data.hxx
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,8 +23,8 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_DATA_HXX
-# define DYN_DATA_HXX
+#ifndef XTC_DATA_HXX
+# define XTC_DATA_HXX
# include <string>
# include <cassert>
@@ -33,14 +33,14 @@
# include "function.hh"
# include "name_of.hh"
-namespace dyn {
+namespace xtc {
template <typename T>
T data::convert_to() const
{
- static fun dyn_data_cast(std::string("data_cast< ") +
+ static fun xtc_data_cast(std::string("data_cast< ") +
type() + ", " + mlc_name<T>::of() + "
>");
- return dyn_data_cast(*this);
+ return xtc_data_cast(*this);
}
@@ -68,19 +68,19 @@ namespace dyn {
data& data::operator=(const T& rhs)
{
assert(proxy_);
- static fun dyn_data_assign(std::string("data_assign<") +
proxy()->type() + ", " + mlc_name<T>::of() + ">");
- dyn_data_assign(*this, rhs);
+ static fun xtc_data_assign(std::string("data_assign<") +
proxy()->type() + ", " + mlc_name<T>::of() + ">");
+ xtc_data_assign(*this, rhs);
return *this;
}
}
-std::ostream& operator<<(std::ostream& ostr, const dyn::data& d);
-std::istream& operator>>(std::istream& istr, dyn::data& d);
-dyn::data& operator++(dyn::data& d);
-dyn::data& operator--(dyn::data& d);
-bool operator!=(const dyn::data& lhs, const dyn::data& rhs);
-bool operator==(const dyn::data& lhs, const dyn::data& rhs);
-dyn::data operator+(const dyn::data& lhs, const dyn::data& rhs);
+std::ostream& operator<<(std::ostream& ostr, const xtc::data& d);
+std::istream& operator>>(std::istream& istr, xtc::data& d);
+xtc::data& operator++(xtc::data& d);
+xtc::data& operator--(xtc::data& d);
+bool operator!=(const xtc::data& lhs, const xtc::data& rhs);
+bool operator==(const xtc::data& lhs, const xtc::data& rhs);
+xtc::data operator+(const xtc::data& lhs, const xtc::data& rhs);
-#endif // ! DYN_DATA_HXX
+#endif // ! XTC_DATA_HXX
diff --git a/extatica/src/dyn.hh b/extatica/src/extatica.hh
similarity index 89%
rename from extatica/src/dyn.hh
rename to extatica/src/extatica.hh
index 1e7cbf8..02261ce 100644
--- a/extatica/src/dyn.hh
+++ b/extatica/src/extatica.hh
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,18 +23,18 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_DYN_HH
-# define DYN_DYN_HH
+#ifndef XTC_EXTATICA_HH
+# define XTC_EXTATICA_HH
# include "config.hh"
-# define DYN_FULL_IMPLEMENTATION
+# define XTC_FULL_IMPLEMENTATION
# include "data.hh"
# include "function.hh"
-namespace dyn
+namespace xtc
{
namespace language
{
@@ -74,13 +74,13 @@ namespace dyn
val(const val& rhs) : data(rhs) { logger << "val(const val&
rhs)" << std::endl; }
};
- typedef ::dyn::fun fun;
- typedef ::dyn::ctor ctor;
- typedef ::dyn::meth meth;
- typedef ::dyn::meth method;
+ typedef ::xtc::fun fun;
+ typedef ::xtc::ctor ctor;
+ typedef ::xtc::meth meth;
+ typedef ::xtc::meth method;
}
}
# include "function_loader.hh"
-#endif // ! DYN_DYN_HH
+#endif // ! XTC_EXTATICA_HH
diff --git a/extatica/src/function_loader.rb b/extatica/src/function_loader.rb
index 1f6c91a..6fb6eb6 100644
--- a/extatica/src/function_loader.rb
+++ b/extatica/src/function_loader.rb
@@ -1,4 +1,5 @@
-# Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE).
+# Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+# Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -16,23 +17,23 @@
require 'pathname'
-DYN_DATADIR = Pathname.new(__FILE__).dirname.parent + '_build/data' # FIXME
+XTC_DATADIR = Pathname.new(__FILE__).dirname.parent + '_build/data' # FIXME
def compile ( cxx, identifier, name, cflags, ldflags )
repository = Pathname.new('repository')
unless repository.exist?
repository.mkpath
- (repository + 'Makefile').make_symlink(DYN_DATADIR +
'Makefile.repository')
+ (repository + 'Makefile').make_symlink(XTC_DATADIR +
'Makefile.repository')
end
dir = repository + identifier
unless dir.exist?
dir.mkpath
- makefile = (DYN_DATADIR + 'Makefile.template').read
- makefile.gsub!(/libdyn_function\.la/, "libdyn_#{identifier}.la")
+ makefile = (XTC_DATADIR + 'Makefile.template').read
+ makefile.gsub!(/libextatica_function\.la/, "libextatica_#{identifier}.la")
(dir + 'Makefile').open('w') { |f| f.puts makefile }
file = dir + "function.cc"
(dir + '.deps').mkpath
- (dir + '.deps' +
'libdyn_function_la-function.Plo').open('w')
+ (dir + '.deps' +
'libextatica_function_la-function.Plo').open('w')
file.open('w') do |f|
f.puts cxx
end
diff --git a/extatica/src/libiberty-fix.c b/extatica/src/libiberty-fix.c
index 6010944..0fb7441 100644
--- a/extatica/src/libiberty-fix.c
+++ b/extatica/src/libiberty-fix.c
@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2009, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -25,7 +25,7 @@
/** \file
- \brief An ugly workaround to have libiberty (glued into libdyn)
+ \brief An ugly workaround to have libiberty (glued into libextatica)
find the \c environ symbol.
Everything should run well as long as we do not use it, nor any
diff --git a/extatica/src/name_of.cc b/extatica/src/name_of.cc
index bf2c24f..41b9170 100644
--- a/extatica/src/name_of.cc
+++ b/extatica/src/name_of.cc
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,8 +23,8 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_NAME_OF_CC
-# define DYN_NAME_OF_CC
+#ifndef XTC_NAME_OF_CC
+# define XTC_NAME_OF_CC
# include "name_of.hh"
@@ -47,4 +47,4 @@ std::string demangle(const char* name)
# endif
-#endif // ! DYN_NAME_OF_CC
+#endif // ! XTC_NAME_OF_CC
diff --git a/extatica/src/name_of.hh b/extatica/src/name_of.hh
index ad688ff..50f801e 100644
--- a/extatica/src/name_of.hh
+++ b/extatica/src/name_of.hh
@@ -1,4 +1,5 @@
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE).
This file is part of Olena.
@@ -23,8 +24,8 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_NAME_OF_HH
-# define DYN_NAME_OF_HH
+#ifndef XTC_NAME_OF_HH
+# define XTC_NAME_OF_HH
# include <typeinfo>
@@ -207,4 +208,4 @@ mlc_set_name(std::ostringstream);
# endif
-#endif // ! DYN_NAME_OF_HH
+#endif // ! XTC_NAME_OF_HH
diff --git a/extatica/src/policy.cc b/extatica/src/policy.cc
index 7ea9bb7..61d314e 100644
--- a/extatica/src/policy.cc
+++ b/extatica/src/policy.cc
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,12 +23,12 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_POLICY_CC
-# define DYN_POLICY_CC
+#ifndef XTC_POLICY_CC
+# define XTC_POLICY_CC
# include "policy.hh"
-namespace dyn
+namespace xtc
{
namespace policy
{
@@ -40,4 +40,4 @@ namespace dyn
}
}
-#endif // ! DYN_POLICY_CC
+#endif // ! XTC_POLICY_CC
diff --git a/extatica/src/policy.hh b/extatica/src/policy.hh
index ef6ce55..7410168 100644
--- a/extatica/src/policy.hh
+++ b/extatica/src/policy.hh
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,21 +23,21 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_POLICY_HH
-# define DYN_POLICY_HH
+#ifndef XTC_POLICY_HH
+# define XTC_POLICY_HH
# include "data.hh"
-namespace dyn
+namespace xtc
{
namespace policy
{
-# define select_dyn_policy(e) \
- (dyn::policy::type)dyn::policy::simplify< \
- sizeof((dyn::policy::id_for_pod_2(), e, dyn::policy::id_for_pod_2())) \
- + sizeof((dyn::policy::id_for_ptr_and_ref_2(), e, \
- dyn::policy::id_for_ptr_and_ref_2()))>::val
+# define select_xtc_policy(e) \
+ (xtc::policy::type)xtc::policy::simplify< \
+ sizeof((xtc::policy::id_for_pod_2(), e, xtc::policy::id_for_pod_2())) \
+ + sizeof((xtc::policy::id_for_ptr_and_ref_2(), e, \
+ xtc::policy::id_for_ptr_and_ref_2()))>::val
template <unsigned n>
struct id
@@ -102,7 +102,7 @@ namespace dyn
receiver& operator,(T& obj)
{
logger << "receiver::operator,(T&) [ T = " <<
mlc_name<T>::of() << " ]" << std::endl;
- proxy_ = new typename dyn_choose_data_proxy<T, policy>::ret(obj);
+ proxy_ = new typename xtc_choose_data_proxy<T, policy>::ret(obj);
return *this;
}
@@ -110,7 +110,7 @@ namespace dyn
receiver& operator,(const T& obj)
{
logger << "receiver::operator,(const T&) [ T = " <<
mlc_name<const T>::of() << " ]" << std::endl;
- proxy_ = new typename dyn_choose_data_proxy<T, policy>::ret(obj);
+ proxy_ = new typename xtc_choose_data_proxy<T, policy>::ret(obj);
return *this;
}
@@ -129,4 +129,4 @@ namespace dyn
}
}
-#endif // ! DYN_POLICY_HH
+#endif // ! XTC_POLICY_HH
diff --git a/extatica/src/ruby_stream.cc b/extatica/src/ruby_stream.cc
index e7f8abe..b44735e 100644
--- a/extatica/src/ruby_stream.cc
+++ b/extatica/src/ruby_stream.cc
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,8 +23,8 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_RUBY_STREAM_CC
-# define DYN_RUBY_STREAM_CC
+#ifndef XTC_RUBY_STREAM_CC
+# define XTC_RUBY_STREAM_CC
# include "ruby_stream.hh"
@@ -33,4 +33,4 @@ namespace ruby
eval_type eval;
}
-#endif // ! DYN_RUBY_STREAM_CC
+#endif // ! XTC_RUBY_STREAM_CC
diff --git a/extatica/src/ruby_stream.hh b/extatica/src/ruby_stream.hh
index f327d20..9b608a4 100644
--- a/extatica/src/ruby_stream.hh
+++ b/extatica/src/ruby_stream.hh
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,8 +23,8 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_RUBY_STREAM_HH
-# define DYN_RUBY_STREAM_HH
+#ifndef XTC_RUBY_STREAM_HH
+# define XTC_RUBY_STREAM_HH
// #define DEBUG_RUBY_STREAM
@@ -122,4 +122,4 @@ ruby::stream& operator<< (ruby::stream& stream, const
T& obj)
return stream;
}
-#endif // ! DYN_RUBY_STREAM_HH
+#endif // ! XTC_RUBY_STREAM_HH
diff --git a/extatica/src/wrappers/Makefile.am b/extatica/src/wrappers/Makefile.am
index af08122..a80a367 100644
--- a/extatica/src/wrappers/Makefile.am
+++ b/extatica/src/wrappers/Makefile.am
@@ -1,4 +1,4 @@
-# Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE).
+# Copyright (C) 2009, 2010 EPITA Research and Development Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -21,5 +21,5 @@
AM_CPPFLAGS = -I$(top_srcdir)/src -I$(top_builddir)/src
# Wrapping a few Milena routines.
-lib_LTLIBRARIES = libdynmilena.la
-libdynmilena_la_SOURCES = milena.hh milena.cc
+lib_LTLIBRARIES = libextatica-milena.la
+libextatica_milena_la_SOURCES = milena.hh milena.cc
diff --git a/extatica/swig/Makefile.am b/extatica/swig/Makefile.am
index 8743680..156421a 100644
--- a/extatica/swig/Makefile.am
+++ b/extatica/swig/Makefile.am
@@ -1,4 +1,4 @@
-# Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE).
+# Copyright (C) 2009, 2010 EPITA Research and Development Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -16,6 +16,6 @@
SUBDIRS = python
-EXTRA_DIST = dyn.i mln.i
+EXTRA_DIST = xtc.i mln.i
check_SCRIPTS = run
diff --git a/extatica/swig/mln.i b/extatica/swig/mln.i
index 0539cfc..320987f 100644
--- a/extatica/swig/mln.i
+++ b/extatica/swig/mln.i
@@ -1,6 +1,6 @@
// -*- C++ -*-
-/* Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2009, 2010 EPITA Research and Development Laboratory (LRDE)
This file is part of Olena.
@@ -26,14 +26,14 @@
executable file might be covered by the GNU General Public License. */
/// \file
-/// \brief A wrapper of libdynmilena.
+/// \brief A wrapper of libextatica-milena.
%module mln
-%import dyn.i
+%import xtc.i
%{
-#include "dyn-all.hh"
+#include "xtc-all.hh"
#include "wrappers/milena.hh"
%}
@@ -42,5 +42,5 @@
%init
%{
// Set up header paths.
- dyn::mln::initialize();
+ xtc::mln::initialize();
%}
diff --git a/extatica/swig/python/Makefile.am b/extatica/swig/python/Makefile.am
index bef9788..51b0be4 100644
--- a/extatica/swig/python/Makefile.am
+++ b/extatica/swig/python/Makefile.am
@@ -32,8 +32,8 @@ AM_SWIGFLAGS = -Wall -c++ -python -I$(top_builddir)/src
-I$(top_srcdir)/src
# We build modules, not plain libs.
AM_LDFLAGS = -avoid-version -module -shared
# Libraries with their dependencies.
-libdyn_la = $(top_builddir)/src/libdyn.la
-libdynmilena_la = $(top_builddir)/src/wrappers/libdynmilena.la $(libdyn_la)
+libextatica_la = $(top_builddir)/src/libextatica.la
+libextatica_milena_la = $(top_builddir)/src/wrappers/libextatica-milena.la
$(libextatica_la)
# Run Swig to create the C++ wrapper files, the Python interface
# files, and the dependency Makefile snippets.
@@ -94,21 +94,21 @@ CLEANFILES = config.py config.py[co]
nodist_python_PYTHON =
pyexec_LTLIBRARIES =
-## dyn.
-pyexec_LTLIBRARIES += _dyn.la
-nodist__dyn_la_SOURCES = dyn-wrap.cc
-_dyn_la_LIBADD = $(libdyn_la)
-CLEANFILES += $(nodist__dyn_la_SOURCES) dyn.py dyn.py[co]
+## xtc.
+pyexec_LTLIBRARIES += _xtc.la
+nodist__xtc_la_SOURCES = xtc-wrap.cc
+_xtc_la_LIBADD = $(libextatica_la)
+CLEANFILES += $(nodist__xtc_la_SOURCES) xtc.py xtc.py[co]
## Include the dependency files. Copied from Automake's generated
## case for C++.
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/_dyn-wrap.Pcc@am__quote@
-nodist_python_PYTHON += dyn.py
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/_xtc-wrap.Pcc@am__quote@
+nodist_python_PYTHON += xtc.py
# FIXME: Should be optional.
## mln.
pyexec_LTLIBRARIES += _mln.la
nodist__mln_la_SOURCES = mln-wrap.cc
-_mln_la_LIBADD = $(libdynmilena_la)
+_mln_la_LIBADD = $(libextatica_milena_la)
CLEANFILES += $(nodist__mln_la_SOURCES) mln.py mln.py[co]
## Include the dependency files. Copied from Automake's generated
## case for C++.
@@ -144,13 +144,13 @@ $(srcdir)/run.stamp: $(RUN_IN)
# and a test. Alas, the script `run' expects a file name with an
# extension as argument. We could improve this by adding options such
# as `--python' to `run'.
-TESTS = milena-libdyn.py milena-libdynmilena.py
+TESTS = milena-libextatica.py milena-libextatica-milena.py
# FIXME: Is this really needed?
EXTRA_DIST += $(TESTS)
-# Log produced by libdyn.
-CLEANFILES += dyn.log
+# Log produced by libextatica.
+CLEANFILES += xtc.log
clean-local: clean-repository
.PHONY: clean-repository
diff --git a/extatica/swig/dyn.i b/extatica/swig/xtc.i
similarity index 80%
rename from extatica/swig/dyn.i
rename to extatica/swig/xtc.i
index 16884ce..a88ef4f 100644
--- a/extatica/swig/dyn.i
+++ b/extatica/swig/xtc.i
@@ -1,6 +1,6 @@
// -*- C++ -*-
-/* Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2009, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -26,42 +26,42 @@
executable file might be covered by the GNU General Public License. */
/// \file
-/// \brief A wrapper of libdyn.
+/// \brief A wrapper of libextatica.
-%module dyn
+%module xtc
%include std_string.i
%{
-#include "dyn-all.hh"
+#include "xtc-all.hh"
%}
// Ignore global objects causing trouble to swig.
-%ignore dyn::logger;
+%ignore xtc::logger;
-%include "dyn-all.hh";
+%include "xtc-all.hh";
/*---------------.
| Construction. |
`---------------*/
-/* The natural, single-argument ctors of dyn::data manipulate the
+/* The natural, single-argument ctors of xtc::data manipulate the
encapsulated member by reference, which is wrong when these data
are of builtin types of the target language (e.g., Pythons'
`int's), because we have no control on them and they can vanish at
any moment.
- To prevent this, provide constructors helpers creating dyn::data
+ To prevent this, provide constructors helpers creating xtc::data
objects manipulating data by value (copy). */
%define generate_data_ctor(Arg, Type)
-%extend dyn::data
+%extend xtc::data
{
data(Arg v)
{
- dyn::proxy_tag* dummy = 0;
+ xtc::proxy_tag* dummy = 0;
// This dummy pointer passed as second argument is required to
// call the right ctor.
- return new dyn::data(new dyn::data_proxy_by_cpy< Type >(v), dummy);
+ return new xtc::data(new xtc::data_proxy_by_cpy< Type >(v), dummy);
}
}
%enddef // !generate_data_ctor
@@ -76,7 +76,7 @@ generate_data_ctor(Type, Type)
generate_data_ctor(const Type &, Type)
%enddef
-// Generate dyn::data ctors using a proxy-by-value for classic types.
+// Generate xtc::data ctors using a proxy-by-value for classic types.
generate_data_ctor_val(int)
generate_data_ctor_ref(std::string)
@@ -84,8 +84,8 @@ generate_data_ctor_ref(std::string)
| Conversions. |
`--------------*/
-// Instantiate dyn::data explicit conversion routines for some types.
-%extend dyn::data
+// Instantiate xtc::data explicit conversion routines for some types.
+%extend xtc::data
{
%template(convert_to_int) convert_to<int>;
%template(convert_to_string) convert_to<std::string>;
diff --git a/extatica/test/Makefile.am b/extatica/test/Makefile.am
index 3317a26..d15aa3b 100644
--- a/extatica/test/Makefile.am
+++ b/extatica/test/Makefile.am
@@ -34,8 +34,8 @@ SUBDIRS = . vaucanson wrappers
#erb# check_PROGRAMS = <%= TESTS.map { |t| "#{t}.test" }.join ' '
%>
#erb# <% TESTS.each do |name| %>
#erb# <%= name %>_test_SOURCES = test_<%= name %>.cc
-#erb# <%= name %>_test_LDADD = $(top_builddir)/src/libdyn.la
-#erb# <%= name %>_test_DEPENDENCIES = $(top_builddir)/src/libdyn.la
+#erb# <%= name %>_test_LDADD = $(top_builddir)/src/libextatica.la
+#erb# <%= name %>_test_DEPENDENCIES = $(top_builddir)/src/libextatica.la
#erb# <% end %>
#erb# =end
@@ -50,28 +50,28 @@ check_PROGRAMS = function_loader.test damien.test containers.test
var_and_val.te
# `check_PROGRAM', stop using erbx.
function_loader_test_SOURCES = test_function_loader.cc
-function_loader_test_LDADD = $(top_builddir)/src/libdyn.la
-function_loader_test_DEPENDENCIES = $(top_builddir)/src/libdyn.la
+function_loader_test_LDADD = $(top_builddir)/src/libextatica.la
+function_loader_test_DEPENDENCIES = $(top_builddir)/src/libextatica.la
damien_test_SOURCES = test_damien.cc
-damien_test_LDADD = $(top_builddir)/src/libdyn.la
-damien_test_DEPENDENCIES = $(top_builddir)/src/libdyn.la
+damien_test_LDADD = $(top_builddir)/src/libextatica.la
+damien_test_DEPENDENCIES = $(top_builddir)/src/libextatica.la
containers_test_SOURCES = test_containers.cc
-containers_test_LDADD = $(top_builddir)/src/libdyn.la
-containers_test_DEPENDENCIES = $(top_builddir)/src/libdyn.la
+containers_test_LDADD = $(top_builddir)/src/libextatica.la
+containers_test_DEPENDENCIES = $(top_builddir)/src/libextatica.la
var_and_val_test_SOURCES = test_var_and_val.cc
-var_and_val_test_LDADD = $(top_builddir)/src/libdyn.la
-var_and_val_test_DEPENDENCIES = $(top_builddir)/src/libdyn.la
+var_and_val_test_LDADD = $(top_builddir)/src/libextatica.la
+var_and_val_test_DEPENDENCIES = $(top_builddir)/src/libextatica.la
methods_test_SOURCES = test_methods.cc
-methods_test_LDADD = $(top_builddir)/src/libdyn.la
-methods_test_DEPENDENCIES = $(top_builddir)/src/libdyn.la
+methods_test_LDADD = $(top_builddir)/src/libextatica.la
+methods_test_DEPENDENCIES = $(top_builddir)/src/libextatica.la
milena_test_SOURCES = test_milena.cc
-milena_test_LDADD = $(top_builddir)/src/libdyn.la
-milena_test_DEPENDENCIES = $(top_builddir)/src/libdyn.la
+milena_test_LDADD = $(top_builddir)/src/libextatica.la
+milena_test_DEPENDENCIES = $(top_builddir)/src/libextatica.la
#erb# =end_generated
@@ -84,8 +84,8 @@ TESTS = $(check_PROGRAMS)
tests: $(check_PROGRAMS)
-# Log produced by libdyn.
-CLEANFILES = dyn.log
+# Log produced by libextatica.
+CLEANFILES = xtc.log
clean-local: clean-repository
.PHONY: clean-repository
diff --git a/extatica/test/test_containers.cc b/extatica/test/test_containers.cc
index 4c06461..b84d5e8 100644
--- a/extatica/test/test_containers.cc
+++ b/extatica/test/test_containers.cc
@@ -1,4 +1,5 @@
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE).
This file is part of Olena.
@@ -27,14 +28,14 @@
#include "my_lib/lib.hh"
-#include "dyn-all.hh"
+#include "xtc-all.hh"
-using namespace dyn::language;
+using namespace xtc::language;
int main()
{
- dyn::include_dir(DYN_FIXTURES);
- dyn::include("my_lib/lib.hh");
+ xtc::include_dir(XTC_FIXTURES);
+ xtc::include("my_lib/lib.hh");
echo("Test containers");
std::vector<int> v(4);
diff --git a/extatica/test/test_damien.cc b/extatica/test/test_damien.cc
index b705acb..1aad127 100644
--- a/extatica/test/test_damien.cc
+++ b/extatica/test/test_damien.cc
@@ -1,4 +1,5 @@
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE).
This file is part of Olena.
@@ -25,11 +26,11 @@
#include "my_lib/damien.hh"
-#include "dyn-all.hh"
+#include "xtc-all.hh"
-using namespace dyn::language;
+using namespace xtc::language;
-namespace dyn
+namespace xtc
{
fun down("mk_down");
@@ -43,8 +44,8 @@ namespace dyn
int main()
{
- dyn::include_dir(DYN_FIXTURES);
- dyn::include("my_lib/damien.hxx");
+ xtc::include_dir(XTC_FIXTURES);
+ xtc::include("my_lib/damien.hxx");
down<char> a('x');
down<int> b(10);
@@ -57,56 +58,56 @@ int main()
std::cout << d2 << std::endl;
- fun dyn_foo("foo");
- fun dyn_change("change");
+ fun xtc_foo("foo");
+ fun xtc_change("change");
ctor mk_down_char("down<char>");
ctor mk_down_int("down<int>");
- meth dyn_print_noarg("print_noarg");
- meth dyn_get_i("get_i");
- meth dyn_get_t("get_t");
- method dyn_clone("clone"); // Same as meth
+ meth xtc_print_noarg("print_noarg");
+ meth xtc_get_i("get_i");
+ meth xtc_get_t("get_t");
+ method xtc_clone("clone"); // Same as meth
var f = mk_down_char('x');
std::cout << mlc_name_of(f) << std::endl;
var g = mk_down_int(44);
- var h = dyn::mk_down(e);
+ var h = xtc::mk_down(e);
- var j = dyn::down(46);
+ var j = xtc::down(46);
meth j_print_noarg = j.method("print_noarg");
// std::cout is not printable
// but a data containing std::cout yes
- var dyn_std_cout = std::cout;
- std::cout << dyn_std_cout << std::endl;
+ var xtc_std_cout = std::cout;
+ std::cout << xtc_std_cout << std::endl;
for ( int i = 0; i < 5; ++i )
{
std::cout << "*** Turn " << i << " ***"
<< std::endl;
- dyn_print_noarg(a);
+ xtc_print_noarg(a);
- dyn_foo(a);
+ xtc_foo(a);
- dyn_foo(b);
- dyn_foo(c);
- dyn_foo(d);
- dyn_foo(e);
- dyn_foo(42);
+ xtc_foo(b);
+ xtc_foo(c);
+ xtc_foo(d);
+ xtc_foo(e);
+ xtc_foo(42);
- dyn_print_noarg(f);
+ xtc_print_noarg(f);
- dyn_foo(g);
+ xtc_foo(g);
- dyn_change(c);
+ xtc_change(c);
- var x1 = dyn_get_i(b);
- std::cout << "dyn_get_i(b) => " << x1 << std::endl;
- var x2 = *dyn_get_t(d);
- std::cout << "dyn_get_t(d) => " << x2 << std::endl;
+ var x1 = xtc_get_i(b);
+ std::cout << "xtc_get_i(b) => " << x1 << std::endl;
+ var x2 = *xtc_get_t(d);
+ std::cout << "xtc_get_t(d) => " << x2 << std::endl;
- var x3 = *dyn_clone(a);
+ var x3 = *xtc_clone(a);
std::cout << "*clone(a) => " << x3 << std::endl;
j.send("print_noarg");
diff --git a/extatica/test/test_function_loader.cc
b/extatica/test/test_function_loader.cc
index b15dc4b..9ac0943 100644
--- a/extatica/test/test_function_loader.cc
+++ b/extatica/test/test_function_loader.cc
@@ -1,4 +1,5 @@
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE).
This file is part of Olena.
@@ -27,24 +28,24 @@
#include "my_lib/lib.hh"
-#include "dyn-all.hh"
+#include "xtc-all.hh"
-using namespace dyn::language;
+using namespace xtc::language;
int main()
{
- dyn::include_dir(DYN_FIXTURES);
+ xtc::include_dir(XTC_FIXTURES);
- dyn::fun dfoo1("foo1", "my_lib/lib.hh"); // With the include
+ xtc::fun dfoo1("foo1", "my_lib/lib.hh"); // With the include
- dyn::include("my_lib/lib.hh"); // setup a default include
+ xtc::include("my_lib/lib.hh"); // setup a default include
- dyn::fun dfoo2("foo2"); // use the default includes
- dyn::fun dfoo2b("foo2b");
- dyn::fun dfoo3("foo3");
- dyn::fun dfoo4("foo4");
- dyn::fun dsqr("my_lib::sqr");
- dyn::fun dpower("my_lib::power");
+ xtc::fun dfoo2("foo2"); // use the default includes
+ xtc::fun dfoo2b("foo2b");
+ xtc::fun dfoo3("foo3");
+ xtc::fun dfoo4("foo4");
+ xtc::fun dsqr("my_lib::sqr");
+ xtc::fun dpower("my_lib::power");
dfoo1();
dfoo1();
diff --git a/extatica/test/test_methods.cc b/extatica/test/test_methods.cc
index 3416a53..63de1fe 100644
--- a/extatica/test/test_methods.cc
+++ b/extatica/test/test_methods.cc
@@ -1,4 +1,5 @@
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE).
This file is part of Olena.
@@ -25,13 +26,13 @@
#include <iostream>
-#include "dyn-all.hh"
+#include "xtc-all.hh"
-using namespace dyn::language;
+using namespace xtc::language;
int main()
{
- dyn::include_dir(DYN_FIXTURES);
+ xtc::include_dir(XTC_FIXTURES);
std::cout << "Test methods" << std::endl;
ctor mk_down_int("down<int>", "my_lib/damien.hh");
diff --git a/extatica/test/test_milena.cc b/extatica/test/test_milena.cc
index ca56416..17f3a79 100644
--- a/extatica/test/test_milena.cc
+++ b/extatica/test/test_milena.cc
@@ -1,4 +1,5 @@
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE).
This file is part of Olena.
@@ -23,17 +24,17 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#include "dyn-all.hh"
+#include "xtc-all.hh"
-using namespace dyn::language;
+using namespace xtc::language;
int main()
{
- dyn::include_dir(MILENA_DIR);
- dyn::include("mln/core/image/image2d.hh");
- dyn::include("mln/data/fill.hh");
- dyn::include("mln/debug/iota.hh");
- dyn::include("mln/debug/println.hh");
+ xtc::include_dir(MILENA_DIR);
+ xtc::include("mln/core/image/image2d.hh");
+ xtc::include("mln/data/fill.hh");
+ xtc::include("mln/debug/iota.hh");
+ xtc::include("mln/debug/println.hh");
ctor mk_image2d_int("mln::image2d<int>");
fun fill("mln::data::fill");
diff --git a/extatica/test/test_var_and_val.cc b/extatica/test/test_var_and_val.cc
index c1e647b..ecddf88 100644
--- a/extatica/test/test_var_and_val.cc
+++ b/extatica/test/test_var_and_val.cc
@@ -1,4 +1,5 @@
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE).
This file is part of Olena.
@@ -25,14 +26,14 @@
#include "my_lib/lib.hh"
-#include "dyn-all.hh"
+#include "xtc-all.hh"
-using namespace dyn::language;
+using namespace xtc::language;
int main()
{
- dyn::include_dir(DYN_FIXTURES);
- dyn::include("my_lib/lib.hh");
+ xtc::include_dir(XTC_FIXTURES);
+ xtc::include("my_lib/lib.hh");
echo("Test vars and vals");
val i = 4;
diff --git a/extatica/test/vaucanson/Makefile.am b/extatica/test/vaucanson/Makefile.am
index fef65ba..25560c3 100644
--- a/extatica/test/vaucanson/Makefile.am
+++ b/extatica/test/vaucanson/Makefile.am
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE).
+# Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -17,7 +17,7 @@
# FIXME: Clean me!
check-local_DISABLE: tree.yml
- @@BIN@@/yaml_to_dyn_decls < $<
+ @@BIN@@/yaml_to_xtc_decls < $<
cp dyn_vaucanson_dyn_mirror.hh @@VCSN@@/src/demos/function_library
wc tree.swig tree.yml dyn_vaucanson_dyn_mirror.hh dyn_vaucanson_methods.yml
diff --git a/extatica/test/wrappers/Makefile.am b/extatica/test/wrappers/Makefile.am
index 56097c1..d950c78 100644
--- a/extatica/test/wrappers/Makefile.am
+++ b/extatica/test/wrappers/Makefile.am
@@ -14,9 +14,9 @@
# You should have received a copy of the GNU General Public License
# along with Olena. If not, see <http://www.gnu.org/licenses/>.
-LDADD = \
- $(top_builddir)/src/wrappers/libdynmilena.la \
- $(top_builddir)/src/libdyn.la
+LDADD = \
+ $(top_builddir)/src/wrappers/libextatica-milena.la \
+ $(top_builddir)/src/libextatica.la
AM_CPPFLAGS = -I$(top_srcdir)/src -I$(top_builddir)/src
check_PROGRAMS = test-milena
@@ -24,8 +24,8 @@ test_milena_SOURCES = test-milena.cc
TESTS = $(check_PROGRAMS)
-# Log produced by libdyn.
-CLEANFILES = dyn.log
+# Log produced by libextatica.
+CLEANFILES = xtc.log
clean-local: clean-repository
.PHONY: clean-repository
diff --git a/extatica/test/wrappers/test-milena.cc
b/extatica/test/wrappers/test-milena.cc
index 036c15d..a29452b 100644
--- a/extatica/test/wrappers/test-milena.cc
+++ b/extatica/test/wrappers/test-milena.cc
@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2009, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -30,11 +30,11 @@
int main()
{
- dyn::mln::initialize();
+ xtc::mln::initialize();
- dyn::language::var ima = dyn::mln::mk_image2d_int(3, 3);
- dyn::mln::fill(ima, 0);
- dyn::mln::println("ima (before) =", ima);
- dyn::mln::iota(ima);
- dyn::mln::println("ima (after) =", ima);
+ xtc::language::var ima = xtc::mln::mk_image2d_int(3, 3);
+ xtc::mln::fill(ima, 0);
+ xtc::mln::println("ima (before) =", ima);
+ xtc::mln::iota(ima);
+ xtc::mln::println("ima (after) =", ima);
}
diff --git a/extatica/src/function.erb.cc b/extatica/src/function.erb.cc
index 93c50b5..49a3361 100644
--- a/extatica/src/function.erb.cc
+++ b/extatica/src/function.erb.cc
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,8 +23,8 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_FUNCTION_CC
-# define DYN_FUNCTION_CC
+#ifndef XTC_FUNCTION_CC
+# define XTC_FUNCTION_CC
# include <cassert>
# include <string>
@@ -32,10 +32,10 @@
# include <list>
# include "function_loader.hh"
-namespace dyn
+namespace xtc
{
- <%- DYN_MAX_ARGUMENTS.times do |i| -%>
+ <%- XTC_MAX_ARGUMENTS.times do |i| -%>
<%- arguments = (0 .. i - 1).map { |j| "const data& arg#{j}"
}.join(', ') -%>
<%- objects = (0 .. i - 1).map { |j| "arg#{j}" } -%>
@@ -43,7 +43,7 @@ namespace dyn
data
generic_fun::operator() (<%= arguments %>) const
{
- typedef data (*func_t)(<%= (['const dyn::data&'] * i).join(',
') %>);
+ typedef data (*func_t)(<%= (['const xtc::data&'] * i).join(',
') %>);
arguments_types_t arguments_types;
if (obj_ptr_)
@@ -58,7 +58,7 @@ namespace dyn
if (obj_ptr_)
{
- typedef data (*func_t2)(<%= (['const dyn::data&'] * (i +
1)).join(', ') %>);
+ typedef data (*func_t2)(<%= (['const xtc::data&'] * (i +
1)).join(', ') %>);
return ((func_t2)ptr)(<%= (['*obj_ptr_'] + objects).join(',
') %>);
}
@@ -67,6 +67,6 @@ namespace dyn
<%- end -%>
-} // end of namespace dyn
+} // end of namespace xtc
-#endif // ! DYN_FUNCTION_CC
+#endif // ! XTC_FUNCTION_CC
diff --git a/extatica/src/function.erb.hh b/extatica/src/function.erb.hh
index c796640..92d163d 100644
--- a/extatica/src/function.erb.hh
+++ b/extatica/src/function.erb.hh
@@ -1,4 +1,5 @@
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE).
This file is part of Olena.
@@ -23,13 +24,13 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_FUNCTION_HH
-# define DYN_FUNCTION_HH
+#ifndef XTC_FUNCTION_HH
+# define XTC_FUNCTION_HH
# include <cassert>
# include <string>
-namespace dyn
+namespace xtc
{
enum fun_kind
@@ -53,7 +54,7 @@ namespace dyn
header_paths_(header_paths), obj_ptr_(obj_ptr) {}
- <%- DYN_MAX_ARGUMENTS.times do |i| -%>
+ <%- XTC_MAX_ARGUMENTS.times do |i| -%>
data
operator() (<%= (["const data&"] * i).join(', ') %>)
const;
<%- end -%>
@@ -83,6 +84,6 @@ namespace dyn
header_paths, obj_ptr) {}
};
-} // end of namespace dyn
+} // end of namespace xtc
-#endif // ! DYN_FUNCTION_HH
+#endif // ! XTC_FUNCTION_HH
diff --git a/extatica/src/function_loader.cc b/extatica/src/function_loader.cc
index 090569f..4cfc194 100644
--- a/extatica/src/function_loader.cc
+++ b/extatica/src/function_loader.cc
@@ -1,4 +1,5 @@
-/* Copyright (C) 2005, 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2009, 2010 EPITA Research and Development
+ Laboratory (LRDE)
This file is part of Olena.
@@ -23,8 +24,8 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_FUNCTION_LOADER_CC
-# define DYN_FUNCTION_LOADER_CC
+#ifndef XTC_FUNCTION_LOADER_CC
+# define XTC_FUNCTION_LOADER_CC
# include <cstdlib>
@@ -46,10 +47,10 @@
// For more details about this, see
//
http://www.gnu.org/prep/standards/html_node/Conditional-Compilation.html
-# ifdef DYN_RUBY_GENERATOR
-# define HAVE_DYN_RUBY_GENERATOR true
+# ifdef XTC_RUBY_GENERATOR
+# define HAVE_XTC_RUBY_GENERATOR true
# else
-# define HAVE_DYN_RUBY_GENERATOR false
+# define HAVE_XTC_RUBY_GENERATOR false
# endif
namespace bfs = boost::filesystem;
@@ -73,7 +74,7 @@ OStream& join(const InputIterator& begin, const
InputIterator& end,
}
-namespace dyn {
+namespace xtc {
ruby::environment ruby_environment;
@@ -147,9 +148,9 @@ namespace dyn {
function_loader_t()
{
lt_dlinit();
- if (HAVE_DYN_RUBY_GENERATOR)
+ if (HAVE_XTC_RUBY_GENERATOR)
{
- ruby << "$: << \"" << DYNDIR <<
"\"" << ruby::eval;
+ ruby << "$: << \"" << XTCDIR <<
"\"" << ruby::eval;
ruby << "require 'function_loader'" << ruby::eval;
ruby << "require 'md5'" << ruby::eval;
ruby << "Signal.trap(:SEGV, 'IGNORE')" << ruby::eval;
@@ -178,16 +179,16 @@ namespace dyn {
bool first_type_is_ptr = false;
str_list::const_iterator it;
- ostr << "#include \"dyn-light.hh\"\n";
+ ostr << "#include \"xtc-light.hh\"\n";
gen_cxx_path<OStream> fun(ostr);
foreach_path_in_paths(paths, fun);
ostr << "extern \"C\" {\n"
- << " namespace dyn {\n"
+ << " namespace xtc {\n"
<< " namespace generated {\n"
<< " data\n"
- << " dyn_" << identifier << "(";
+ << " xtc_" << identifier << "(";
int i = 0;
for (it = args.begin(); it != args.end(); ++it, ++i)
@@ -256,7 +257,7 @@ namespace dyn {
// no break here
case METH:
case FUN:
- body << "policy::receiver<select_dyn_policy(("
+ body << "policy::receiver<select_xtc_policy(("
<< call.str() << "))> receiver;" << nl
<< "(receiver(), " << call.str() << ");"
<< nl
<< "data ret(receiver.proxy(), (proxy_tag*)0);" << nl
@@ -308,13 +309,13 @@ namespace dyn {
cxx_compile(const std::string& cxx, const std::string& identifier,
const std::string& cflags, const std::string& ldflags)
{
- bfs::path dyn_datadir(DYN_DATADIR);
+ bfs::path xtc_datadir(XTC_DATADIR);
bfs::path repository("repository");
if (!bfs::exists(repository))
{
bfs::create_directory(repository);
- bfs::create_symlink(dyn_datadir / "Makefile.repository",
+ bfs::create_symlink(xtc_datadir / "Makefile.repository",
repository / "Makefile");
}
@@ -323,32 +324,32 @@ namespace dyn {
{
bfs::create_directory(dir);
- bfs::ifstream makefile_orig_str(dyn_datadir / "Makefile.template");
+ bfs::ifstream makefile_orig_str(xtc_datadir / "Makefile.template");
std::stringstream makefile_orig;
makefile_orig << makefile_orig_str.rdbuf();
bfs::ofstream makefile(dir / "Makefile");
/* FIXME: We might want to use boost::format in several
places here, since
- (boost::format("libdyn_%1%.la") % identifier).str()
+ (boost::format("libextatica_%1%.la") % identifier).str()
may be more elegant than
- std::string("libdyn_") + identifier + ".la")
+ std::string("libextatica_") + identifier + ".la")
*/
/* FIXME: It would be more elegant if we could replace
- `libdyn_function.la' on the fly while copying the
+ `libextatica_function.la' on the fly while copying the
Makefile (as we would do with Perl). See what Boost
proposes. */
makefile <<
ba::replace_all_copy(makefile_orig.str(),
- "libdyn_function.la",
- std::string("libdyn_") + identifier + ".la");
+ "libextatica_function.la",
+ std::string("libextatica_") + identifier + ".la");
makefile << "CXXFLAGS += " << cflags << std::endl;
makefile << "LDFLAGS += " << ldflags << std::endl;
bfs::create_directory(dir / ".deps");
- bfs::ofstream(dir / ".deps" / "libdyn_function_la-function.Plo");
+ bfs::ofstream(dir / ".deps" /
"libextatica_function_la-function.Plo");
bfs::path file = dir / "function.cc";
bfs::ofstream function(file);
@@ -434,8 +435,8 @@ namespace dyn {
const char* error;
std::string lib_path = std::string("repository/") + identifier
- + "/libdyn_" + identifier + ".la";
- std::string symb = std::string("dyn_") + identifier;
+ + "/libextatica_" + identifier + ".la";
+ std::string symb = std::string("xtc_") + identifier;
lt_dlhandle lib = lt_dlopen(lib_path.c_str());
if ((error = lt_dlerror())) std::cerr << error << std::endl;
@@ -525,8 +526,8 @@ namespace dyn {
const char* error;
std::string lib_path = std::string("repository/") + identifier
- + "/libdyn_" + identifier + ".la";
- std::string symb = std::string("dyn_") + identifier;
+ + "/libextatica_" + identifier + ".la";
+ std::string symb = std::string("xtc_") + identifier;
lt_dlhandle lib = lt_dlopen(lib_path.c_str());
if ((error = lt_dlerror())) std::cerr << error << std::endl;
@@ -580,7 +581,7 @@ namespace dyn {
const arguments_types_t& arguments_types,
const std::string& header_path)
{
- if (HAVE_DYN_RUBY_GENERATOR)
+ if (HAVE_XTC_RUBY_GENERATOR)
return function_loader.ruby_load(kind, name, arguments_types,
header_path);
else
@@ -588,6 +589,6 @@ namespace dyn {
header_path);
}
-} // end of namespace dyn
+} // end of namespace xtc
-#endif // ! DYN_FUNCTION_LOADER_CC
+#endif // ! XTC_FUNCTION_LOADER_CC
diff --git a/extatica/src/function_loader.hh b/extatica/src/function_loader.hh
index b57d9b5..69b5548 100644
--- a/extatica/src/function_loader.hh
+++ b/extatica/src/function_loader.hh
@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2005, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,13 +23,13 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_FUNCTION_LOADER_HH
-# define DYN_FUNCTION_LOADER_HH
+#ifndef XTC_FUNCTION_LOADER_HH
+# define XTC_FUNCTION_LOADER_HH
# include <string>
# include <list>
-namespace dyn {
+namespace xtc {
void
include(const std::string& file);
@@ -49,6 +49,6 @@ namespace dyn {
const arguments_types_t& arguments_types,
const std::string& header_path);
-} // end of namespace dyn
+} // end of namespace xtc
-#endif // ! DYN_FUNCTION_LOADER_HH
+#endif // ! XTC_FUNCTION_LOADER_HH
diff --git a/extatica/src/wrappers/milena.cc b/extatica/src/wrappers/milena.cc
index 5f9bc95..2b92754 100644
--- a/extatica/src/wrappers/milena.cc
+++ b/extatica/src/wrappers/milena.cc
@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2009, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -31,7 +31,7 @@
/// \todo The next step is to generate (semi-)automatically this file
/// from Milena's (possibly annotated) source files.
-namespace dyn
+namespace xtc
{
namespace mln
@@ -43,11 +43,11 @@ namespace dyn
void initialize()
{
- dyn::include_dir(MILENA_DIR);
- dyn::include("mln/core/image/image2d.hh");
- dyn::include("mln/data/fill.hh");
- dyn::include("mln/debug/iota.hh");
- dyn::include("mln/debug/println.hh");
+ xtc::include_dir(MILENA_DIR);
+ xtc::include("mln/core/image/image2d.hh");
+ xtc::include("mln/data/fill.hh");
+ xtc::include("mln/debug/iota.hh");
+ xtc::include("mln/debug/println.hh");
}
@@ -65,6 +65,6 @@ namespace dyn
// ...
- } // end of namespace dyn::mln
+ } // end of namespace xtc::mln
-} // end of namespace dyn
+} // end of namespace xtc
diff --git a/extatica/src/wrappers/milena.hh b/extatica/src/wrappers/milena.hh
index 87e8253..9fd6c4e 100644
--- a/extatica/src/wrappers/milena.hh
+++ b/extatica/src/wrappers/milena.hh
@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
+/* Copyright (C) 2009, 2010 EPITA Research and Development Laboratory (LRDE).
This file is part of Olena.
@@ -23,8 +23,8 @@
exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License. */
-#ifndef DYN_WRAPPERS_MILENA_HH
-# define DYN_WRAPPERS_MILENA_HH
+#ifndef XTC_WRAPPERS_MILENA_HH
+# define XTC_WRAPPERS_MILENA_HH
/// \file
/// \brief Declaration of Milena wrappers.
@@ -32,9 +32,9 @@
/// \todo The next step is to generate (semi-)automatically this file
/// from Milena's (possibly annotated) source files.
-# include <dyn-all.hh>
+# include <xtc-all.hh>
-namespace dyn
+namespace xtc
{
namespace mln
@@ -47,7 +47,7 @@ namespace dyn
/* FIXME: This is not really elegant, but this is a lot safer than
the previous approach relying on the (implementation-defined)
order of initialization of global objects' ctors. We can
- probably improve this by reworking dyn::function_loader. See
+ probably improve this by reworking xtc::function_loader. See
also hints and advice from
http://en.allexperts.com/q/C-1040/Constructors-Global-Object.htm. */
@@ -61,18 +61,18 @@ namespace dyn
| A few wrapped routines. |
`-------------------------*/
- extern dyn::language::ctor mk_image2d_int;
+ extern xtc::language::ctor mk_image2d_int;
- extern dyn::language::fun fill;
- extern dyn::language::fun iota;
- extern dyn::language::fun println;
+ extern xtc::language::fun fill;
+ extern xtc::language::fun iota;
+ extern xtc::language::fun println;
// FIXME: Wrap more routines.
// ...
- } // end of namespace dyn::mln
+ } // end of namespace xtc::mln
-} // end of namespace dyn
+} // end of namespace xtc
-#endif // ! DYN_WRAPPERS_MILENA_HH
+#endif // ! XTC_WRAPPERS_MILENA_HH
diff --git a/extatica/swig/python/milena-libdynmilena.py
b/extatica/swig/python/milena-libextatica-milena.py
similarity index 65%
rename from extatica/swig/python/milena-libdynmilena.py
rename to extatica/swig/python/milena-libextatica-milena.py
index 037a429..49307f4 100644
--- a/extatica/swig/python/milena-libdynmilena.py
+++ b/extatica/swig/python/milena-libextatica-milena.py
@@ -1,6 +1,6 @@
#! /usr/bin/env python
-# Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
+# Copyright (C) 2009, 2010 EPITA Research and Development Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -17,27 +17,27 @@
# along with Olena. If not, see <http://www.gnu.org/licenses/>.
# \file
-# \brief A Python version of test/test_milena.cc using libdynmilena.
+# \brief A Python version of test/test_milena.cc using libextatica-milena.
import ltihooks
-import dyn
+import xtc
import mln
# We'd like to be able to write this:
#
# ima = mln.mk_image2d_int(3, 3)
#
# but we just can't. `mk_image2d_int' only accept `dyn.data' as
# arguments, so we have to encapsulate integers in `dyn.data' objects
# (likewise for strings).
#
# Moreover, mk_image2d_int is a global object (functor), registered as
# an attribute of the `mln.cvar' object.
-ima = mln.cvar.mk_image2d_int(dyn.data(3), dyn.data(3))
+ima = mln.cvar.mk_image2d_int(xtc.data(3), xtc.data(3))
-mln.cvar.fill(ima, dyn.data(0))
-mln.cvar.println(dyn.data("ima (before) ="), ima)
+mln.cvar.fill(ima, xtc.data(0))
+mln.cvar.println(xtc.data("ima (before) ="), ima)
mln.cvar.iota(ima)
-mln.cvar.println(dyn.data("ima (after) ="), ima)
+mln.cvar.println(xtc.data("ima (after) ="), ima)
@@ -17,27 +17,27 @@
# ima = mln.mk_image2d_int(3, 3)
#
-# but we just can't. `mk_image2d_int' only accept `dyn.data' as
-# arguments, so we have to encapsulate integers in `dyn.data' objects
+# but we just can't. `mk_image2d_int' only accept `xtc.data' as
+# arguments, so we have to encapsulate integers in `xtc.data' objects
# (likewise for strings).
#
diff --git a/extatica/swig/python/milena-libdyn.py
b/extatica/swig/python/milena-libextatica.py
similarity index 52%
rename from extatica/swig/python/milena-libdyn.py
rename to extatica/swig/python/milena-libextatica.py
index 65e6fe9..2224822 100644
--- a/extatica/swig/python/milena-libdyn.py
+++ b/extatica/swig/python/milena-libextatica.py
@@ -1,6 +1,6 @@
#! /usr/bin/env python
-# Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
+# Copyright (C) 2009, 2010 EPITA Research and Development Laboratory (LRDE).
#
# This file is part of Olena.
#
@@ -17,25 +17,25 @@
# along with Olena. If not, see <http://www.gnu.org/licenses/>.
# \file
-# \brief A Python version of test/test_milena.cc using libdyn (directly).
+# \brief A Python version of test/test_milena.cc using libextatica (directly).
import ltihooks
-import dyn
+import xtc
import config
# Set up paths.
-dyn.include_dir(config.abs_milena_dir)
-dyn.include("mln/core/image/image2d.hh")
-dyn.include("mln/data/fill.hh")
-dyn.include("mln/debug/iota.hh")
-dyn.include("mln/debug/println.hh")
+xtc.include_dir(config.abs_milena_dir)
+xtc.include("mln/core/image/image2d.hh")
+xtc.include("mln/data/fill.hh")
+xtc.include("mln/debug/iota.hh")
+xtc.include("mln/debug/println.hh")
# Instantiate functors.
-mk_image2d_int = dyn.ctor("mln::image2d<int>")
-fill = dyn.fun("mln::data::fill")
-iota = dyn.fun("mln::debug::iota")
-println = dyn.fun("mln::debug::println")
+mk_image2d_int = xtc.ctor("mln::image2d<int>")
+fill = xtc.fun("mln::data::fill")
+iota = xtc.fun("mln::debug::iota")
+println = xtc.fun("mln::debug::println")
# Use them (by compiling them on-the-fly).
@@ -43,13 +43,13 @@ println = dyn.fun("mln::debug::println")
#
# ima = mk_image2d_int(3, 3)
#
# but we just can't. `mk_image2d_int' only accept `dyn.data' as
# arguments, so we have to encapsulate integers in `dyn.data' objects
# (likewise for strings).
-ima = mk_image2d_int(dyn.data(3), dyn.data(3))
+ima = mk_image2d_int(xtc.data(3), xtc.data(3))
-fill(ima, dyn.data(0))
-println(dyn.data("ima (before) ="), ima)
+fill(ima, xtc.data(0))
+println(xtc.data("ima (before) ="), ima)
iota(ima)
-println(dyn.data("ima (after) ="), ima)
+println(xtc.data("ima (after) ="), ima)
@@ -43,13 +43,13 @@ println = dyn.fun("mln::debug::println")
# ima = mk_image2d_int(3, 3)
#
-# but we just can't. `mk_image2d_int' only accept `dyn.data' as
-# arguments, so we have to encapsulate integers in `dyn.data' objects
+# but we just can't. `mk_image2d_int' only accept `xtc.data' as
+# arguments, so we have to encapsulate integers in `xtc.data' objects
# (likewise for strings).
--
1.5.6.5